..
    Copyright (C) 2022 University of Münster.


    DNB-Urn-Service is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

===============
DNB-Urn-Service
===============

This module for InvenioRDM wraps a thin python layer around the DNB REST-API's to directly mint new and changed URN's.

Configuration
=============

No configuration is necessary.
